package com.lantone.daqe.facade;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lantone.common.enums.IsDeleteEnum;
import com.lantone.common.exception.Asserts;
import com.lantone.common.util.BeanUtil;
import com.lantone.common.util.ListUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.common.util.SysUserUtils;
import com.lantone.daqe.dto.GetByIdColumnResultDTO;
import com.lantone.daqe.dto.GetColumnResultNumberDTO;
import com.lantone.daqe.dto.GetColumnResultPageDTO;
import com.lantone.daqe.dto.GetRegular;
import com.lantone.daqe.dto.GetStandardvalueInfoDTO;
import com.lantone.daqe.dto.GetTableColumnInfoDTO;
import com.lantone.daqe.entity.BehospitalInfo;
import com.lantone.daqe.entity.ColumnInfo;
import com.lantone.daqe.entity.ColumnResult;
import com.lantone.daqe.entity.NonnullInfo;
import com.lantone.daqe.entity.NonnullResult;
import com.lantone.daqe.entity.RegularResult;
import com.lantone.daqe.entity.StandardvalueResult;
import com.lantone.daqe.enums.AuditStatusEnum;
import com.lantone.daqe.enums.ColumnResultTypeEnum;
import com.lantone.daqe.enums.ColumnTypeEnum;
import com.lantone.daqe.enums.ColumnVerifyTypeEnum;
import com.lantone.daqe.enums.ModeEnum;
import com.lantone.daqe.enums.NonnullStatusEnum;
import com.lantone.daqe.enums.SolvedStatusEnum;
import com.lantone.daqe.facade.base.BehospitalInfoFacade;
import com.lantone.daqe.facade.base.ColumnInfoFacade;
import com.lantone.daqe.facade.base.ColumnResultFacade;
import com.lantone.daqe.facade.base.NonnullInfoFacade;
import com.lantone.daqe.facade.base.NonnullResultFacade;
import com.lantone.daqe.facade.base.RegularMappingFacade;
import com.lantone.daqe.facade.base.RegularResultFacade;
import com.lantone.daqe.facade.base.StandardvalueInfoFacade;
import com.lantone.daqe.facade.base.StandardvalueResultFacade;
import com.lantone.daqe.vo.DataCheckVO;
import com.lantone.daqe.vo.GetColumnResultNumberVO;
import com.lantone.daqe.vo.GetColumnResultPageVO;
import com.lantone.daqe.vo.GetRegularMappingVO;
import com.lantone.daqe.vo.GetStandardvalueInfoVO;
import com.lantone.daqe.vo.GetTableColumnInfoVO;
import com.lantone.daqe.vo.UpdateColumnResultVO;
import com.lantone.daqe.vo.GetByIdColumnResultVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;


/**
 * @Description: 字段校验问题明细维护API
 * @author： zhanghang
 * @time: 2022/3/8 14:49
 */
@Component
public class ColumnResultManagementFacade {
    @Autowired
    ColumnResultFacade columnResultFacade;
    @Autowired
    NonnullResultFacade nonnullResultFacade;
    @Autowired
    RegularResultFacade regularResultFacade;
    @Autowired
    StandardvalueResultFacade standardvalueResultFacade;
    @Autowired
    BehospitalInfoFacade behospitalInfoFacade;
    @Autowired
    NonnullInfoFacade nonnullInfoFacade;
    @Autowired
    RegularMappingFacade regularMappingFacade;
    @Autowired
    StandardvalueInfoFacade standardvalueInfoFacade;
    @Autowired
    ColumnInfoFacade columnInfoFacade;

    /**
     * 获取字段校验问题明细分页列表数据
     *
     * @param getColumnResultPageVO
     * @return: 字段校验问题明细分页列表数据
     */
    public IPage<GetColumnResultPageDTO> getColumnResultPage(GetColumnResultPageVO getColumnResultPageVO) {
        Page<GetColumnResultPageDTO> getColumnResultPageDTOPage = new Page<>();
        Long currentHospitalId = SysUserUtils.getCurrentHospitalId();
        getColumnResultPageVO.setHospitalId(SysUserUtils.getCurrentHospitalId()==null?4:SysUserUtils.getCurrentHospitalId());
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String startDate = null;
        String endDate = null;
        if (getColumnResultPageVO.getSolveTimeStart() != null) {
            startDate = sdf.format(getColumnResultPageVO.getSolveTimeStart());
        }
        if (getColumnResultPageVO.getSolveTimeEnd() != null) {
            endDate = sdf.format(getColumnResultPageVO.getSolveTimeEnd());
        }
        QueryWrapper<ColumnResult> columnResultQueryWrapper = new QueryWrapper<>();
        columnResultQueryWrapper.eq(getColumnResultPageVO.getHospitalId() != null, "hospital_id", getColumnResultPageVO.getHospitalId());
        columnResultQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey());
        columnResultQueryWrapper.eq(StringUtil.isNotBlank(getColumnResultPageVO.getType()), "type", getColumnResultPageVO.getType());
        columnResultQueryWrapper.eq(StringUtil.isNotBlank(getColumnResultPageVO.getIsSolved()), "is_solved", getColumnResultPageVO.getIsSolved());
        columnResultQueryWrapper.ge(StringUtil.isNotBlank(startDate), "solve_time", getColumnResultPageVO.getSolveTimeStart());
        columnResultQueryWrapper.le(StringUtil.isNotBlank(endDate), "solve_time", getColumnResultPageVO.getSolveTimeEnd());
        columnResultQueryWrapper.like(StringUtil.isNotBlank(getColumnResultPageVO.getBehospitalCode()), "behospital_code", getColumnResultPageVO.getBehospitalCode());
        columnResultQueryWrapper.like(StringUtil.isNotBlank(getColumnResultPageVO.getHosptialDatatmpCode()), "hosptial_datatmp_code", getColumnResultPageVO.getHosptialDatatmpCode());
        columnResultQueryWrapper.like(StringUtil.isNotBlank(getColumnResultPageVO.getHosptialDatatmpName()), "hosptial_datatmp_name", getColumnResultPageVO.getHosptialDatatmpName());
        columnResultQueryWrapper.like(StringUtil.isNotBlank(getColumnResultPageVO.getModeName()), "mode_name", getColumnResultPageVO.getModeName());

        Page<ColumnResult> columnResultPage = new Page<>(getColumnResultPageVO.getCurrent(), getColumnResultPageVO.getSize());
        columnResultFacade.page(columnResultPage, columnResultQueryWrapper);
        BeanUtil.copyProperties(columnResultPage, getColumnResultPageDTOPage);
        List<GetColumnResultPageDTO> getRecordTemplatePageDTOList = BeanUtil.listCopyTo(columnResultPage.getRecords(), GetColumnResultPageDTO.class);

        getColumnResultPageDTOPage.setRecords(getRecordTemplatePageDTOList);
        return getColumnResultPageDTOPage;
    }

    /**
     * 获取字段校验问题明细数量
     *
     * @param getColumnResultNumberVO
     * @return: 字段校验问题明细数量
     */
    public GetColumnResultNumberDTO getColumnResultNumber(GetColumnResultNumberVO getColumnResultNumberVO) {
        Long currentHospitalId = SysUserUtils.getCurrentHospitalId();
        getColumnResultNumberVO.setHospitalId(SysUserUtils.getCurrentHospitalId()==null?4:SysUserUtils.getCurrentHospitalId());
        return columnResultFacade.getBaseMapper().getColumnResultNumber(getColumnResultNumberVO);
    }

    /**
     * 修改字段校验问题明细
     *
     * @param updateColumnResultVO
     * @return: 是否成功
     */
    public Boolean updateColumnResult(UpdateColumnResultVO updateColumnResultVO) {
        ColumnResult columnResultFacadeById = columnResultFacade.getById(updateColumnResultVO.getId());
        //先修改副表
        //非空校验结果表
        Long resultId = columnResultFacadeById.getResultId();
        String type = columnResultFacadeById.getType();
        if (ColumnVerifyTypeEnum.NONNULL_TYPE.getKey().equals(type)) {
            nonnullResultFacade.update(new UpdateWrapper<NonnullResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
                    .set("description", updateColumnResultVO.getDescription())
                    .set("gmt_modified", new Date())
            );
        }
        //正则校验结果表
        if (ColumnVerifyTypeEnum.REGULAR_TYPE.getKey().equals(type)) {
            regularResultFacade.update(new UpdateWrapper<RegularResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
                    .set("description", updateColumnResultVO.getDescription())
                    .set("gmt_modified", new Date())
            );
        }
        //关键字校验结果表
        if (ColumnVerifyTypeEnum.STANDARD_TYPE.getKey().equals(type)) {
            standardvalueResultFacade.update(new UpdateWrapper<StandardvalueResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
                    .set("description", updateColumnResultVO.getDescription())
                    .set("gmt_modified", new Date())
            );
        }

        return columnResultFacade.update(new UpdateWrapper<ColumnResult>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", updateColumnResultVO.getId())
                .set("description", updateColumnResultVO.getDescription())
                .set("gmt_modified", new Date())
        );
    }

    /**
     * 根据ID查看字段校验问题明细
     *
     * @param getByIdColumnResultVO
     * @return: 字段校验问题明细明细
     */
    public GetByIdColumnResultDTO getByIdColumnResult(GetByIdColumnResultVO getByIdColumnResultVO) {
        ColumnResult columnResult = columnResultFacade.getBaseMapper().selectById(getByIdColumnResultVO.getId());
        String type = columnResult.getType();
        GetByIdColumnResultDTO getByIdColumnResultDTO = new GetByIdColumnResultDTO();
        //非空校验
        if (ColumnVerifyTypeEnum.NONNULL_TYPE.getKey().equals(type)) {
            getByIdColumnResultDTO.setType(type);
            Long resultId = columnResult.getResultId();
            NonnullResult nonnullResult = nonnullResultFacade.getBaseMapper().selectOne(new QueryWrapper<NonnullResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
            );
            BeanUtil.copyProperties(nonnullResult, getByIdColumnResultDTO);
            return getByIdColumnResultDTO;
        }
        //正则校验结果表
        if (ColumnVerifyTypeEnum.REGULAR_TYPE.getKey().equals(type)) {
            getByIdColumnResultDTO.setType(type);
            Long resultId = columnResult.getResultId();
            RegularResult regularResult = regularResultFacade.getBaseMapper().selectOne(new QueryWrapper<RegularResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
            );
            BeanUtil.copyProperties(regularResult, getByIdColumnResultDTO);
            return getByIdColumnResultDTO;
        }
        //关键字校验结果表
        if (ColumnVerifyTypeEnum.STANDARD_TYPE.getKey().equals(type)) {
            getByIdColumnResultDTO.setType(type);
            Long resultId = columnResult.getResultId();
            StandardvalueResult standardvalueResult = standardvalueResultFacade.getBaseMapper().selectOne(new QueryWrapper<StandardvalueResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("id", resultId)
            );
            BeanUtil.copyProperties(standardvalueResult, getByIdColumnResultDTO);
            return getByIdColumnResultDTO;
        }
        return getByIdColumnResultDTO;
    }

    /**
     * 数据校验接口
     *
     * @param dataCheckVO
     * @return: 是否成功
     */
    public Boolean dataCheck(DataCheckVO dataCheckVO) {
        Long currentHospitalId = SysUserUtils.getCurrentHospitalId();
        dataCheckVO.setHospitalId(SysUserUtils.getCurrentHospitalId()==null?4:SysUserUtils.getCurrentHospitalId());
        String behospitalCode = dataCheckVO.getBehospitalCode();
        //传入BehospitalCode 只针对单个病历进行校验
        if (StringUtil.isNotEmpty(behospitalCode)) {
            checkTableColumnVal(dataCheckVO);
        }
        //对于只传时间不传病历的情况
        if (StringUtil.isEmpty(behospitalCode)) {
            //先获取字段校验结果表中所有未解决的情况
            List<ColumnResult> columnResultsList = columnResultFacade.getBaseMapper().selectList(new QueryWrapper<ColumnResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("is_solved", SolvedStatusEnum.NOT_SOLVED.getKey())
            );
            for (ColumnResult columnResult : columnResultsList) {
                Long columnId = columnResult.getColumnId();
                //为空校验
                if (ColumnResultTypeEnum.NONNULL_TYPE.getKey().equals(columnResult.getType())) {
                    //先获取非空的字段校验规则
                    List<NonnullInfo> nonnullInfos = nonnullInfoFacade.getBaseMapper().selectList(new QueryWrapper<NonnullInfo>()
                            .eq("is_deleted", IsDeleteEnum.N.getKey())
                            .eq("column_id", columnId)
                    );
                    if (ListUtil.isNotEmpty(nonnullInfos)) {
                        for (NonnullInfo nonnullInfo : nonnullInfos) {
                            ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                            GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                            getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                            getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                            getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                            getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                            getTableColumnInfoVO.setBehospitalCode(columnResult.getBehospitalCode());
                            getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                            String columnNumber = getColumnNumber(columnInfo.getTableCname());
                            getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                            List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                            for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                                String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                                String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                                getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                                getTableColumnInfoDTO.setModeName(modeName);
                                String val = getTableColumnInfoDTO.getVal();
                                if (NonnullStatusEnum.NOT_NONNULL.equals(nonnullInfo.getIsRequired())) {
                                    //调用修改非空校验结果表信息中已解决修改
                                    updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                    continue;
                                }
                                if (StringUtil.isNotEmpty(val)) {
                                    //调用修改非空校验结果表信息中已解决修改
                                    updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                }
                                if (StringUtil.isEmpty(val)) {
                                    //存在 则修改 不存在则新增
                                    //调用修改非空校验结果表信息中未解决修改
                                    updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                    continue;
                                }
                            }
                        }
                    }
                }

                //正则校验
                if (ColumnResultTypeEnum.REGULAR_TYPE.getKey().equals(columnResult.getType())) {
                    //获取正则字段校验规则
                    GetRegularMappingVO getRegularMappingVO = new GetRegularMappingVO();
                    getRegularMappingVO.setColumnId(columnId);
                    List<GetRegular> regularMappings = regularMappingFacade.getBaseMapper().getRegularMapping(getRegularMappingVO);
                    if (ListUtil.isNotEmpty(regularMappings)) {
                        for (GetRegular getRegular : regularMappings) {
                            ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                            GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                            getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                            getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                            getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                            getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                            getTableColumnInfoVO.setBehospitalCode(columnResult.getBehospitalCode());
                            getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                            String columnNumber = getColumnNumber(columnInfo.getTableCname());
                            getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                            List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                            String regular = getRegular.getVal();
                            for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                                String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                                String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                                getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                                getTableColumnInfoDTO.setModeName(modeName);
                                String val = getTableColumnInfoDTO.getVal();
                                boolean matches = val.matches(regular);
                                //符合正则  存在则修改，没有则跳过
                                if (matches) {
                                    updateRegularResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                                }
                                //不符合正则
                                if (!matches) {
                                    //原有存在修改
                                    updateRegularResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                }
                            }
                        }
                    }
                }
                //标准校验
                if (ColumnResultTypeEnum.STANDARD_TYPE.getKey().equals(columnResult.getType())) {
                    //获取字段校验的标准值规则
                    GetStandardvalueInfoVO getStandardvalueInfoVO = new GetStandardvalueInfoVO();
                    getStandardvalueInfoVO.setColumnId(columnId);
                    List<GetStandardvalueInfoDTO> standardvalueInfos = standardvalueInfoFacade.getBaseMapper().getStandardvalueInfo(getStandardvalueInfoVO);
                    if (ListUtil.isNotEmpty(standardvalueInfos)) {
                        for (GetStandardvalueInfoDTO standardvalueInfo : standardvalueInfos) {
                            ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                            GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                            getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                            getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                            getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                            getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                            getTableColumnInfoVO.setBehospitalCode(columnResult.getBehospitalCode());
                            getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                            String columnNumber = getColumnNumber(columnInfo.getTableCname());
                            getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                            List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                            String standardvalue = standardvalueInfo.getStandardvalue();
                            for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                                String standardvalueMapping = getStandardvalueMapping(standardvalue, dataCheckVO.getHospitalId());
                                String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                                String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                                getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                                getTableColumnInfoDTO.setModeName(modeName);
                                String val = getTableColumnInfoDTO.getVal();
                                //判断是否符合标准值
                                boolean contains = standardvalue.contains(val);
                                //符合标准值，若原表存在则修改，若不存在则直接跳过
                                if (contains) {
                                    updateStandardvalueResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey(), standardvalueMapping);
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());

                                }
                                //不符合标准值  若原表存在则修改，若不存在则新增
                                if (!contains) {
                                    updateStandardvalueResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey(), standardvalueMapping);
                                    updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                }
                            }
                        }
                    }
                }
            }
            //再去除该时间段所有病历中去除病历中已通过的字段
            List<BehospitalInfo> behospitalInfos = behospitalInfoFacade.getBaseMapper().selectList(new QueryWrapper<BehospitalInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("is_placefile", 1)
                    .ge("behospital_date", dataCheckVO.getDateStart())
                    .le("behospital_date", dataCheckVO.getDateEnd())
            );
            for (BehospitalInfo behospitalInfo : behospitalInfos) {
                String behospitalCode1 = behospitalInfo.getBehospitalCode();
                //先获取非空的所有字段校验规则
                List<NonnullInfo> nonnullInfos = nonnullInfoFacade.getBaseMapper().selectList(new QueryWrapper<NonnullInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                );
                if (ListUtil.isNotEmpty(nonnullInfos)) {
                    for (NonnullInfo nonnullInfo : nonnullInfos) {
                        Long columnId = nonnullInfo.getColumnId();
                        ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                        NonnullResult nonnullResult1 = nonnullResultFacade.getBaseMapper().selectOne(new QueryWrapper<NonnullResult>()
                                .eq("hospital_id", dataCheckVO.getHospitalId())
                                .eq("is_deleted", IsDeleteEnum.N.getKey())
                                .eq("behospital_code", behospitalCode1)
                                .eq("column_id", columnId)
                        );
                        if (nonnullResult1 != null) {
                            continue;
                        }
                        GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                        getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                        getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                        getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                        getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                        getTableColumnInfoVO.setBehospitalCode(behospitalCode1);
                        getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                        String columnNumber = getColumnNumber(columnInfo.getTableCname());
                        getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                        List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                        for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                            String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                            String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                            getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                            getTableColumnInfoDTO.setModeName(modeName);
                            String val = getTableColumnInfoDTO.getVal();
                            if (NonnullStatusEnum.NOT_NONNULL.equals(nonnullInfo.getIsRequired())) {
                                continue;
                            }
                            if (StringUtil.isNotEmpty(val)) {
                                continue;
                            }
                            if (StringUtil.isEmpty(val)) {
                                //为空加入非空校验结果表
                                NonnullResult nonnullResult = new NonnullResult();
                                nonnullResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                                nonnullResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                                nonnullResult.setModeId(getTableColumnInfoDTO.getModeId());
                                nonnullResult.setModeName(getTableColumnInfoDTO.getModeName());
                                nonnullResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                                nonnullResult.setColumnId(columnId);
                                nonnullResult.setTableCname(columnInfo.getTableCname());
                                nonnullResult.setTableEname(columnInfo.getTableEname());
                                nonnullResult.setColumnCname(columnInfo.getColumnCname());
                                nonnullResult.setColumnEname(columnInfo.getColumnEname());
                                nonnullResult.setTableId(getTableColumnInfoDTO.getTableId());
                                nonnullResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                                nonnullResult.setSolveTime(new Date());
                                nonnullResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                                nonnullResult.setGmtCreate(new Date());
                                nonnullResultFacade.getBaseMapper().insert(nonnullResult);
                                Long id = nonnullInfo.getId();
                                //加入总结果表
                                addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.NONNULL_TYPE.getKey());
                            }
                        }
                    }
                }
                //获取正则所有字段校验规则
                GetRegularMappingVO getRegularMappingVO = new GetRegularMappingVO();
                List<GetRegular> regularMappings = regularMappingFacade.getBaseMapper().getRegularMapping(getRegularMappingVO);
                if (ListUtil.isNotEmpty(regularMappings)) {
                    for (GetRegular getRegular : regularMappings) {
                        Long columnId = getRegular.getColumnId();
                        RegularResult regularResults = regularResultFacade.getBaseMapper().selectOne(new QueryWrapper<RegularResult>()
                                .eq("is_deleted", IsDeleteEnum.N.getKey())
                                .eq("hospital_id", dataCheckVO.getHospitalId())
                                .eq("behospital_code", behospitalCode1)
                                .eq("column_id", columnId)
                        );
                        if (regularResults != null) {
                            continue;
                        }
                        ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                        GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                        getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                        getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                        getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                        getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                        getTableColumnInfoVO.setBehospitalCode(behospitalCode1);
                        getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                        String columnNumber = getColumnNumber(columnInfo.getTableCname());
                        getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                        List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                        String regular = getRegular.getVal();
                        for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                            String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                            String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                            getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                            getTableColumnInfoDTO.setModeName(modeName);
                            String val = getTableColumnInfoDTO.getVal();
                            boolean matches = val.matches(regular);
                            //符合正则  存在则修改，没有则跳过
                            if (matches) {
                                continue;
                            }
                            //不符合正则
                            if (!matches) {
                                //为空加入非空校验结果表
                                RegularResult regularResult = new RegularResult();
                                regularResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                                regularResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                                regularResult.setModeId(getTableColumnInfoDTO.getModeId());
                                regularResult.setModeName(getTableColumnInfoDTO.getModeName());
                                regularResult.setColumnId(columnId);
                                regularResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                                regularResult.setTableCname(columnInfo.getTableCname());
                                regularResult.setTableEname(columnInfo.getTableEname());
                                regularResult.setColumnCname(columnInfo.getColumnCname());
                                regularResult.setColumnEname(columnInfo.getColumnEname());
                                regularResult.setRegularId(getRegular.getId());
                                regularResult.setRegularName(getRegular.getName());
                                regularResult.setRegularVal(getRegular.getVal());
                                regularResult.setRegularDes(getRegular.getDes());
                                regularResult.setTableId(getTableColumnInfoDTO.getTableId());
                                regularResult.setTableVal(getTableColumnInfoDTO.getVal());
                                regularResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                                regularResult.setSolveTime(new Date());
                                regularResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                                regularResult.setGmtCreate(new Date());
                                regularResultFacade.getBaseMapper().insert(regularResult);
                                Long id = regularResult.getId();
                                //加入总结果表
                                addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.REGULAR_TYPE.getKey());
                            }
                        }
                    }
                }
                //获取字段校验的标准值规则
                GetStandardvalueInfoVO getStandardvalueInfoVO = new GetStandardvalueInfoVO();
                List<GetStandardvalueInfoDTO> standardvalueInfos = standardvalueInfoFacade.getBaseMapper().getStandardvalueInfo(getStandardvalueInfoVO);
                if (ListUtil.isNotEmpty(standardvalueInfos)) {
                    for (GetStandardvalueInfoDTO standardvalueInfo : standardvalueInfos) {
                        Long columnId = standardvalueInfo.getColumnId();
                        StandardvalueResult standardvalueResult1 = standardvalueResultFacade.getBaseMapper().selectOne(new QueryWrapper<StandardvalueResult>()
                                .eq("is_deleted", IsDeleteEnum.N.getKey())
                                .eq("hospital_id", dataCheckVO.getHospitalId())
                                .eq("behospital_code", behospitalCode1)
                                .eq("column_id", columnId)
                        );
                        if (standardvalueResult1 != null) {
                            continue;
                        }
                        ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                        GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                        getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                        getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                        getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                        getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                        getTableColumnInfoVO.setBehospitalCode(behospitalCode1);
                        getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                        String columnNumber = getColumnNumber(columnInfo.getTableCname());
                        getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                        List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                        String standardvalue = standardvalueInfo.getStandardvalue();
                        for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                            String standardvalueMapping = getStandardvalueMapping(standardvalue, dataCheckVO.getHospitalId());
                            String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                            String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                            getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                            getTableColumnInfoDTO.setModeName(modeName);
                            String val = getTableColumnInfoDTO.getVal();
                            //判断是否符合标准值
                            boolean contains = standardvalue.contains(val);
                            //符合标准值，若原表存在则修改，若不存在则直接跳过
                            if (contains) {
                                continue;
                            }
                            //不符合标准值  若原表存在则修改，若不存在则新增
                            if (!contains) {
                                //为空加入非空校验结果表
                                StandardvalueResult standardvalueResult = new StandardvalueResult();
                                standardvalueResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                                standardvalueResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                                standardvalueResult.setModeId(getTableColumnInfoDTO.getModeId());
                                standardvalueResult.setModeName(getTableColumnInfoDTO.getModeName());
                                standardvalueResult.setColumnId(columnId);
                                standardvalueResult.setMappings(standardvalueMapping);
                                standardvalueResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                                standardvalueResult.setTableCname(columnInfo.getTableCname());
                                standardvalueResult.setTableEname(columnInfo.getTableEname());
                                standardvalueResult.setColumnCname(columnInfo.getColumnCname());
                                standardvalueResult.setColumnEname(columnInfo.getColumnEname());
                                standardvalueResult.setTableId(getTableColumnInfoDTO.getTableId());
                                standardvalueResult.setTableVal(getTableColumnInfoDTO.getVal());
                                standardvalueResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                                standardvalueResult.setSolveTime(new Date());
                                standardvalueResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                                standardvalueResult.setGmtCreate(new Date());
                                standardvalueResultFacade.getBaseMapper().insert(standardvalueResult);
                                Long id = standardvalueResult.getId();
                                //加入总结果表
                                addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.STANDARD_TYPE.getKey());
                            }
                        }
                    }
                }
            }
        }
        return true;
    }

    /**
     * 根据表名称字段名称获取具体数据
     *
     * @param getTableColumnInfoVO
     * @return: 具体数据
     */
    public List<GetTableColumnInfoDTO> getTableColumnVal(GetTableColumnInfoVO getTableColumnInfoVO) {
        List<GetTableColumnInfoDTO> tableColumnVal = columnResultFacade.getBaseMapper().getTableColumnVal(getTableColumnInfoVO);
        return tableColumnVal;
    }

    /**
     * 对于单个病历校验其表信息字段
     *
     * @param dataCheckVO
     * @return: 具体数据
     */
    public void checkTableColumnVal(DataCheckVO dataCheckVO) {
        String behospitalCode = dataCheckVO.getBehospitalCode();
        if (StringUtil.isNotEmpty(behospitalCode)) {
            List<BehospitalInfo> behospitalInfos = behospitalInfoFacade.getBaseMapper().selectList(new QueryWrapper<BehospitalInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("behospital_code", dataCheckVO.getBehospitalCode())
                    .eq("hospital_id", dataCheckVO.getHospitalId())
            );
            if (ListUtil.isEmpty(behospitalInfos)) {
                Asserts.fail("该患者信息未查询到！");
            }
            //先获取非空的所有字段校验规则
            List<NonnullInfo> nonnullInfos = nonnullInfoFacade.getBaseMapper().selectList(new QueryWrapper<NonnullInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
            );
            if (ListUtil.isNotEmpty(nonnullInfos)) {
                for (NonnullInfo nonnullInfo : nonnullInfos) {
                    Long columnId = nonnullInfo.getColumnId();
                    ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                    GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                    getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                    getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                    getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                    getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                    getTableColumnInfoVO.setBehospitalCode(dataCheckVO.getBehospitalCode());
                    getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                    String columnNumber = getColumnNumber(columnInfo.getTableCname());
                    getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                    List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                    for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                        String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                        String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                        getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                        getTableColumnInfoDTO.setModeName(modeName);
                        String val = getTableColumnInfoDTO.getVal();
                        //不是必填则判断是否存在，若存在则更新，若不存在则跳过
                        if (NonnullStatusEnum.NOT_NONNULL.equals(nonnullInfo.getIsRequired())) {
                            NonnullResult nonnullResult1 = getNonnullResult(getTableColumnInfoDTO, columnId);
                            if (nonnullResult1 == null) {
                                continue;
                            }
                            //调用修改非空校验结果表信息中已解决修改
                            updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                            updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                            continue;
                        }

                        if (StringUtil.isNotEmpty(val)) {
                            NonnullResult nonnullResult1 = getNonnullResult(getTableColumnInfoDTO, columnId);
                            if (nonnullResult1 == null) {
                                continue;
                            }
                            //调用修改非空校验结果表信息中已解决修改
                            updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                            updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                        }
                        if (StringUtil.isEmpty(val)) {
                            //先判断原表是否含有此问题数据
                            NonnullResult nonnullResult1 = getNonnullResult(getTableColumnInfoDTO, columnId);
                            if (nonnullResult1 != null) {
                                //存在 则修改 不存在则新增
                                //调用修改非空校验结果表信息中未解决修改
                                updateNonnullResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                continue;
                            }
                            //为空加入非空校验结果表
                            NonnullResult nonnullResult = new NonnullResult();
                            nonnullResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                            nonnullResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                            nonnullResult.setModeId(getTableColumnInfoDTO.getModeId());
                            nonnullResult.setModeName(getTableColumnInfoDTO.getModeName());
                            nonnullResult.setColumnId(nonnullInfo.getColumnId());
                            nonnullResult.setTableCname(columnInfo.getTableCname());
                            nonnullResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                            nonnullResult.setTableEname(columnInfo.getTableEname());
                            nonnullResult.setColumnCname(columnInfo.getColumnCname());
                            nonnullResult.setColumnEname(columnInfo.getColumnEname());
                            nonnullResult.setTableId(getTableColumnInfoDTO.getTableId());
                            nonnullResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                            nonnullResult.setSolveTime(new Date());
                            nonnullResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                            nonnullResult.setGmtCreate(new Date());
                            nonnullResultFacade.getBaseMapper().insert(nonnullResult);
                            Long id = nonnullInfo.getId();
                            //加入总结果表
                            addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.NONNULL_TYPE.getKey());
                        }
                    }
                }
            }
            //获取正则所有字段校验规则
            GetRegularMappingVO getRegularMappingVO = new GetRegularMappingVO();
            List<GetRegular> regularMappings = regularMappingFacade.getBaseMapper().getRegularMapping(getRegularMappingVO);

            if (ListUtil.isNotEmpty(regularMappings)) {
                for (GetRegular getRegular : regularMappings) {
                    Long columnId = getRegular.getColumnId();
                    ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                    GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                    getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                    getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                    getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                    getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                    getTableColumnInfoVO.setBehospitalCode(dataCheckVO.getBehospitalCode());
                    getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                    String columnNumber = getColumnNumber(columnInfo.getTableCname());
                    getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                    List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                    String regular = getRegular.getVal();
                    for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                        String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                        String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                        getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                        getTableColumnInfoDTO.setModeName(modeName);
                        String val = getTableColumnInfoDTO.getVal();
                        boolean matches = val.matches(regular);
                        //符合正则  存在则修改，没有则跳过
                        if (matches) {
                            RegularResult regularResult1 = getRegularResult(getTableColumnInfoDTO, columnId);
                            if (regularResult1 == null) {
                                continue;
                            }
                            updateRegularResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());
                            updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());

                        }
                        //不符合正则
                        if (!matches) {
                            //先判断原表是否含有此问题数据
                            RegularResult regularResult1 = getRegularResult(getTableColumnInfoDTO, columnId);
                            if (regularResult1 != null) {
                                //原有存在修改
                                updateRegularResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                continue;
                            }
                            //为空加入非空校验结果表
                            RegularResult regularResult = new RegularResult();
                            regularResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                            regularResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                            regularResult.setModeId(getTableColumnInfoDTO.getModeId());
                            regularResult.setModeName(getTableColumnInfoDTO.getModeName());
                            regularResult.setColumnId(columnId);
                            regularResult.setTableCname(columnInfo.getTableCname());
                            regularResult.setTableEname(columnInfo.getTableEname());
                            regularResult.setColumnCname(columnInfo.getColumnCname());
                            regularResult.setColumnEname(columnInfo.getColumnEname());
                            regularResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                            regularResult.setRegularId(getRegular.getId());
                            regularResult.setRegularName(getRegular.getName());
                            regularResult.setRegularVal(getRegular.getVal());
                            regularResult.setRegularDes(getRegular.getDes());
                            regularResult.setTableId(getTableColumnInfoDTO.getTableId());
                            regularResult.setTableVal(getTableColumnInfoDTO.getVal());
                            regularResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                            regularResult.setSolveTime(new Date());
                            regularResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                            regularResult.setGmtCreate(new Date());
                            regularResultFacade.getBaseMapper().insert(regularResult);
                            Long id = regularResult.getId();
                            //加入总结果表
                            addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.REGULAR_TYPE.getKey());
                        }
                    }
                }
            }
            //获取字段校验的标准值规则
            GetStandardvalueInfoVO getStandardvalueInfoVO = new GetStandardvalueInfoVO();
            List<GetStandardvalueInfoDTO> standardvalueInfos = standardvalueInfoFacade.getBaseMapper().getStandardvalueInfo(getStandardvalueInfoVO);
            if (ListUtil.isNotEmpty(standardvalueInfos)) {
                for (GetStandardvalueInfoDTO standardvalueInfo : standardvalueInfos) {
                    Long columnId = standardvalueInfo.getColumnId();
                    ColumnInfo columnInfo = columnInfoFacade.getBaseMapper().selectById(columnId);
                    GetTableColumnInfoVO getTableColumnInfoVO = new GetTableColumnInfoVO();
                    getTableColumnInfoVO.setColumnCname(columnInfo.getColumnCname());
                    getTableColumnInfoVO.setColumnEname(columnInfo.getColumnEname());
                    getTableColumnInfoVO.setTableCname(columnInfo.getTableCname());
                    getTableColumnInfoVO.setTableEname(columnInfo.getTableEname());
                    getTableColumnInfoVO.setBehospitalCode(dataCheckVO.getBehospitalCode());
                    getTableColumnInfoVO.setHospitalId(dataCheckVO.getHospitalId());
                    String columnNumber = getColumnNumber(columnInfo.getTableCname());
                    getTableColumnInfoVO.setNumberColumnCname(columnNumber);
                    List<GetTableColumnInfoDTO> tableColumnVal = getTableColumnVal(getTableColumnInfoVO);
                    String standardvalue = standardvalueInfo.getStandardvalue();
                    for (GetTableColumnInfoDTO getTableColumnInfoDTO : tableColumnVal) {
                        String modeId = ModeEnum.valueOf(columnInfo.getTableEname()).getKey();
                        String modeName = ModeEnum.valueOf(columnInfo.getTableEname()).getName();
                        getTableColumnInfoDTO.setModeId(Long.valueOf(modeId));
                        getTableColumnInfoDTO.setModeName(modeName);
                        String val = getTableColumnInfoDTO.getVal();
                        //判断是否符合标准值
                        boolean contains = standardvalue.contains(val);
                        String standardvalueMapping = getStandardvalueMapping(standardvalue, dataCheckVO.getHospitalId());
                        //符合标准值，若原表存在则修改，若不存在则直接跳过
                        if (contains) {
                            StandardvalueResult standardvalueResult1 = getStandardvalueResult(getTableColumnInfoDTO, columnId);
                            if (standardvalueResult1 == null) {
                                continue;
                            }
                            updateStandardvalueResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey(), standardvalueMapping);
                            updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.IS_SOLVED.getKey());

                        }
                        //不符合标准值  若原表存在则修改，若不存在则新增
                        if (!contains) {
                            //先判断原表是否含有此问题数据
                            StandardvalueResult standardvalueResult1 = getStandardvalueResult(getTableColumnInfoDTO, columnId);
                            if (standardvalueResult1 != null) {
                                updateStandardvalueResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey(), standardvalueMapping);
                                updateColumnResultSolved(getTableColumnInfoDTO, columnId, SolvedStatusEnum.NOT_SOLVED.getKey());
                                continue;
                            }
                            //为空加入校验结果表
                            StandardvalueResult standardvalueResult = new StandardvalueResult();
                            standardvalueResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
                            standardvalueResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
                            standardvalueResult.setModeId(getTableColumnInfoDTO.getModeId());
                            standardvalueResult.setModeName(getTableColumnInfoDTO.getModeName());
                            standardvalueResult.setColumnId(columnId);
                            standardvalueResult.setMappings(standardvalueMapping);
                            standardvalueResult.setTableCname(columnInfo.getTableCname());
                            standardvalueResult.setTableEname(columnInfo.getTableEname());
                            standardvalueResult.setColumnCname(columnInfo.getColumnCname());
                            standardvalueResult.setColumnEname(columnInfo.getColumnEname());
                            standardvalueResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
                            standardvalueResult.setTableId(getTableColumnInfoDTO.getTableId());
                            standardvalueResult.setTableVal(getTableColumnInfoDTO.getVal());
                            standardvalueResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
                            standardvalueResult.setSolveTime(new Date());
                            standardvalueResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
                            standardvalueResult.setGmtCreate(new Date());
                            standardvalueResultFacade.getBaseMapper().insert(standardvalueResult);
                            Long id = standardvalueResult.getId();
                            //加入总结果表
                            addColumnResult(getTableColumnInfoDTO, columnInfo, columnId, id, ColumnResultTypeEnum.STANDARD_TYPE.getKey());
                        }
                    }
                }
            }
        }
    }

    /**
     * 获取非空校验结果表中的数据
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @return: 非空校验表结果信息
     */
    public NonnullResult getNonnullResult(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId) {
        return nonnullResultFacade.getBaseMapper().selectOne(new QueryWrapper<NonnullResult>()
                .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                .eq("column_id", columnId)
                .eq("table_id", getTableColumnInfoDTO.getTableId())
        );
    }

    /**
     * 获取正则结果表中的数据
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @return: 校验表结果信息
     */
    public RegularResult getRegularResult(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId) {
        return regularResultFacade.getBaseMapper().selectOne(new QueryWrapper<RegularResult>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                .eq("column_id", columnId)
                .eq("table_id", getTableColumnInfoDTO.getTableId())
        );
    }

    /**
     * 获取关键值结果表中的数据
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @return: 校验表结果信息
     */
    public StandardvalueResult getStandardvalueResult(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId) {
        return standardvalueResultFacade.getBaseMapper().selectOne(new QueryWrapper<StandardvalueResult>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                .eq("column_id", columnId)
                .eq("table_id", getTableColumnInfoDTO.getTableId())
        );
    }

    /**
     * 修改非空校验结果表信息
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @param type
     * @return:
     */
    public void updateNonnullResultSolved(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId, String type) {
        if (SolvedStatusEnum.NOT_SOLVED.getKey().equals(type)) {
            //未解决修改
            nonnullResultFacade.update(new UpdateWrapper<NonnullResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.NOT_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
        //已解决修改
        if (SolvedStatusEnum.IS_SOLVED.getKey().equals(type)) {
            nonnullResultFacade.update(new UpdateWrapper<NonnullResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.IS_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
    }

    /**
     * 修改正则校验结果表信息
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @param type
     * @return:
     */
    public void updateRegularResultSolved(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId, String type) {
        if (SolvedStatusEnum.NOT_SOLVED.getKey().equals(type)) {
            //未解决修改
            regularResultFacade.update(new UpdateWrapper<RegularResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.NOT_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
        //已解决修改
        if (SolvedStatusEnum.IS_SOLVED.getKey().equals(type)) {
            regularResultFacade.update(new UpdateWrapper<RegularResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.IS_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
    }

    /**
     * 修改关键字校验结果表信息
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @param type
     * @return:
     */
    public void updateStandardvalueResultSolved(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId, String type, String standardvalueMapping) {
        if (SolvedStatusEnum.NOT_SOLVED.getKey().equals(type)) {
            //未解决修改
            standardvalueResultFacade.update(new UpdateWrapper<StandardvalueResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.NOT_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
                    .set("mappings", standardvalueMapping)
            );
        }
        //已解决修改
        if (SolvedStatusEnum.IS_SOLVED.getKey().equals(type)) {
            standardvalueResultFacade.update(new UpdateWrapper<StandardvalueResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.IS_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
                    .set("mappings", standardvalueMapping)
            );
        }
    }

    /**
     * 修改结果总表
     *
     * @param getTableColumnInfoDTO
     * @param columnId
     * @param type
     * @return:
     */
    public void updateColumnResultSolved(GetTableColumnInfoDTO getTableColumnInfoDTO, Long columnId, String type) {
        if (SolvedStatusEnum.NOT_SOLVED.getKey().equals(type)) {
            //未解决修改
            columnResultFacade.update(new UpdateWrapper<ColumnResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.NOT_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
        //已解决修改
        if (SolvedStatusEnum.IS_SOLVED.getKey().equals(type)) {
            columnResultFacade.update(new UpdateWrapper<ColumnResult>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", getTableColumnInfoDTO.getHospitalId())
                    .eq("behospital_code", getTableColumnInfoDTO.getBehospitalCode())
                    .eq("column_id", columnId)
                    .eq("table_id", getTableColumnInfoDTO.getTableId())
                    .set("table_val", getTableColumnInfoDTO.getVal())
                    .set("is_solved", SolvedStatusEnum.IS_SOLVED.getKey())
                    .set("solve_time", new Date())
                    .set("hospital_data_code", getTableColumnInfoDTO.getNumberId())
            );
        }
    }

    /**
     * 新增校验结果总表信息
     *
     * @param getTableColumnInfoDTO
     * @param columnInfo
     * @param columnId
     * @param id
     * @param type
     * @return:
     */
    public void addColumnResult(GetTableColumnInfoDTO getTableColumnInfoDTO, ColumnInfo columnInfo, Long columnId, Long id, String type) {
        ColumnResult columnResult = new ColumnResult();
        columnResult.setHospitalId(getTableColumnInfoDTO.getHospitalId());
        columnResult.setBehospitalCode(getTableColumnInfoDTO.getBehospitalCode());
        columnResult.setModeId(getTableColumnInfoDTO.getModeId());
        columnResult.setModeName(getTableColumnInfoDTO.getModeName());
        columnResult.setHospitalDataCode(getTableColumnInfoDTO.getNumberId());
        columnResult.setColumnId(columnId);
        columnResult.setTableCname(columnInfo.getTableCname());
        columnResult.setTableEname(columnInfo.getTableEname());
        columnResult.setColumnCname(columnInfo.getColumnCname());
        columnResult.setColumnEname(columnInfo.getColumnEname());
        columnResult.setTableId(getTableColumnInfoDTO.getTableId());
        columnResult.setTableVal(getTableColumnInfoDTO.getVal());
        //数据缺失
        if (ColumnResultTypeEnum.NONNULL_TYPE.getKey().equals(type)) {
            columnResult.setType(ColumnResultTypeEnum.NONNULL_TYPE.getKey());
        }
        //关键值
        if (ColumnResultTypeEnum.STANDARD_TYPE.getKey().equals(type)) {
            columnResult.setType(ColumnResultTypeEnum.STANDARD_TYPE.getKey());
        }
        //正则
        if (ColumnResultTypeEnum.REGULAR_TYPE.getKey().equals(type)) {
            columnResult.setType(ColumnResultTypeEnum.REGULAR_TYPE.getKey());
        }
        columnResult.setResultId(id);
        columnResult.setIsSolved(SolvedStatusEnum.NOT_SOLVED.getKey());
        columnResult.setSolveTime(new Date());
        columnResult.setIsAudited(AuditStatusEnum.NOT_AUDIT.getKey());
        columnResult.setGmtCreate(new Date());
        columnResultFacade.getBaseMapper().insert(columnResult);
    }


    /**
     * 根据表明获取该表的编号字段
     *
     * @param tableCname
     * @return:
     */
    public String getColumnNumber(String tableCname) {
        String columnEname = null;
        List<ColumnInfo> columnInfoList = columnInfoFacade.getBaseMapper().selectList(new QueryWrapper<ColumnInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("type", ColumnTypeEnum.FIELD_NUMBER.getKey())
        );
        for (ColumnInfo columnInfo : columnInfoList) {
            String tableCname1 = columnInfo.getTableCname();
            if (tableCname.equals(tableCname1)) {
                columnEname = columnInfo.getColumnEname();
            }
        }
        return columnEname;
    }

    /**
     * 获取关键值映射
     *
     * @param standardvalue
     * @param hospitalId
     * @return:
     */
    public String getStandardvalueMapping(String standardvalue, Long hospitalId) {
        String[] split = standardvalue.split(";");
        StringBuffer stringBuffer = new StringBuffer();
        for (String s : split) {
            stringBuffer = stringBuffer.append(hospitalId).append("-").append(s).append(",");
        }
        String toString = stringBuffer.deleteCharAt(stringBuffer.length() - 1).toString();
        return toString;
    }

}
